@@ -1,8 +1,14 @@
-/* $Id: os-linux.h,v 1.1 1993/10/28 16:50:11 chip Exp $
+/* $Id: os-linux.h,v 1.3 1998/01/11 02:34:18 chip Exp $
  *
  * Deliver configuration for Linux.
  *
  * $Log: os-linux.h,v $
+ * Revision 1.3  1998/01/11 02:34:18  chip
+ * Add HAS_BASENAME.
+ *
+ * Revision 1.2  1994/10/14 20:08:32  chip
+ * Lock only with flock().
+ *
  * Revision 1.1  1993/10/28  16:50:11  chip
  * Initial revision
  *
@@ -24,6 +30,9 @@
 #define HAS_GETHOSTNAME		/* Has gethostname()	     (BSD)	*/
 
 #undef  LOCK_LOCKF		/* Use lockf(F_LOCK, ...)    (SVID)	*/
-#define LOCK_FCNTL		/* Use fcntl(F_SETLKW, ...)  (SVID)	*/
+#define LOCK_FLOCK		/* Use flock(..., LOCK_EX)   (BSD)	*/
 
+#undef  ML_DOTLOCK		/* Create <mailbox>.lock		*/
+
+#define HAS_BASENAME		/* Has basename()			*/
 #define HAS_USLEEP		/* Has usleep() (in microseconds)	*/
